from bluer_options.host.functions import (
    get_name_,
    get_name,
    get_seed_filename,
    is_64bit,
    is_aws_batch,
    is_docker,
    is_ec2,
    is_github_workflow,
    is_headless,
    is_jetson,
    is_jupyter,
    is_mac,
    is_rpi,
    is_ssh_session,
    is_ubuntu,
    signature,
    tensor_processing_signature,
)
